import "Turbine.UI.Lotro"

SHOW_DEBUG_OPTIONS = false;

OptionWindow = class(Turbine.UI.Lotro.Window);

function OptionWindow:Constructor(settings)
	Turbine.UI.Lotro.Window.Constructor(self);

	self.settings = settings;
	self:SetPosition( 200, 200 );
	self:SetText("MinstrelBuff - Options");
	self:SetSize( 270, 400 );
	self:SetVisible(false);
	
	self:PlaceControls(self);
end

function OptionWindow:GetOptionControl()
	local control = Turbine.UI.Control();
	local height = 550;
	if (SHOW_DEBUG_OPTIONS) then
		height = height + 200;
	end
	control:SetSize( 270, height );
	self:PlaceControls(control);
	return control;
end

function OptionWindow:MakeOptionCheckbox(parent, y, optionName)
    local checkbox = Turbine.UI.Lotro.CheckBox();
    checkbox:SetParent(parent);
    checkbox:SetText(_LANG.OPTIONS[optionName]);
    checkbox:SetPosition( 20, y );
    checkbox:SetSize( 230, 25 );
    checkbox:SetChecked(self.settings:GetSetting(optionName));
    checkbox.CheckedChanged = function (sender, args)
        self.settings:SetSetting(
            optionName,
            checkbox:IsChecked());
    end
	return checkbox;
end

function OptionWindow:PlaceControls(parent)
	-- Combat Visibility
	self.combatVisibleCheckBox = self:MakeOptionCheckbox(parent, 40, "EffectWindowOnlyVisibleInCombat");

	-- Theme options
	local themeLabel = Turbine.UI.Label();
	themeLabel:SetPosition( 20, 70 );
	themeLabel:SetSize( 230, 20 );
	themeLabel:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
	themeLabel:SetText(_LANG.OPTIONS.ThemeIndex);
	themeLabel:SetParent(parent);
	
	local themeList = self.settings:GetThemeList();
	local themeIndex = self.settings:GetThemeIndex();
	local themeCount = #themeList;
	
	self.listBox = Turbine.UI.ListBox();
	self.listBox:SetParent( parent );
	self.listBox:SetBackColor( Turbine.UI.Color( 0.2, 0.2, 0.2 ) );
	self.listBox:SetPosition( 20, 100 );
	self.listBox:SetSize( 230, 20 * themeCount );

	for i = 1, themeCount do
		local listItem = Turbine.UI.Label();
		listItem:SetSize( 230, 20 );
		listItem:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
		listItem:SetText(themeList[i].name);
		self.listBox:AddItem( listItem );
	end
	self.listBox:SetSelectedIndex(themeIndex);
	self:ColorListBoxIndex(self.listBox);
	self.listBox.SelectedIndexChanged = function (sender, args) self:ThemeChanged(sender); end

	local y = 100 + 20 * themeCount + 20;

	-- Soliloquy Visibility
	self.soliloquyVisibleCheckBox = self:MakeOptionCheckbox(parent, y, "SolilquyWindowUsed");
	y = y + 40;

	-- Checking for Serious Business
	self.seriousBusinessCheckbox = self:MakeOptionCheckbox(parent, y, "CheckForSeriousBusiness");
    y = y + 40;

	-- Show War-Speech Timers:
	self.showWarSpeechTimersCheckbox = self:MakeOptionCheckbox(parent, y, "ShowWarSpeechTimers");
    y = y + 40;

    -- Show Melodic Interlude Window:
    self.showMelodicInterludeCheckbox = self:MakeOptionCheckbox(parent, y, "ShowMelodicInterlude");
    y = y + 40;

	-- Size of Melodic Interlude Window:
	local miWindowProportionalWidth = self.settings:GetSetting("MelodicInterludeWidth"); -- e.g. 0.026 (2.6%)
	local screenWidth = Turbine.UI.Display:GetWidth(); -- e.g. 1920
	local miWindowActualWidth = miWindowProportionalWidth * screenWidth; -- e.g. 2.6% * 1920 = ~50 (49.92)

	local miWindowDefaultWidth = MelodicInterludeWindow.GetDefaultWidth(); -- e.g. 100
	local miWindowScaledWidth = miWindowActualWidth / miWindowDefaultWidth; -- e.g. 49.92 / 100 = 50%
	-- scollbar is using integer values between 5 and 100 to represent 0.5 to 10.0.
	-- Multiple here:
	local scalingScrollbarValue = miWindowScaledWidth * 10;

	-- Label for the Melodic Interlude window scaling scrollbar
    self.scalingScrollbarLabel = Turbine.UI.Label();
    self.scalingScrollbarLabel:SetParent(parent);
    self.scalingScrollbarLabel:SetSize(300, 25);
    self.scalingScrollbarLabel:SetText(string.format(_LANG.OPTIONS["MelodicInterludeWidth"], miWindowScaledWidth));
    self.scalingScrollbarLabel:SetPosition(20, y);
	y = y + 30;

    -- Scrollbar to adjust Melodic Interlude window size
    self.scalingScrollbar = Turbine.UI.Lotro.ScrollBar();
    self.scalingScrollbar:SetParent(parent);
    self.scalingScrollbar:SetOrientation(Turbine.UI.Orientation.Horizontal);
    self.scalingScrollbar:SetSize(200, 10);
    self.scalingScrollbar:SetPosition(20, y);
    self.scalingScrollbar:SetMinimum(5);
    self.scalingScrollbar:SetMaximum(100);
    self.scalingScrollbar:SetValue(scalingScrollbarValue);
    self.scalingScrollbar.ValueChanged = function(sender, args)
        local currentValue = self.scalingScrollbar:GetValue(); -- e.g. 32
        local scaledValue = currentValue / 10; -- 3.2x

        -- practical minimum: 1x = 32x32, in 1920 x 1080 => 32/1920 = about 1.6%
        -- practical maximum: 10x = 320x320, about 16%

        self.scalingScrollbarLabel:SetText(string.format(_LANG.OPTIONS["MelodicInterludeWidth"], scaledValue));

		local screenWidth = Turbine.UI.Display:GetWidth();
		local actualWidth = scaledValue * MelodicInterludeWindow.GetDefaultWidth();
		local proportinalWidth = actualWidth / screenWidth;
		self.settings:SetSetting("MelodicInterludeWidth", proportinalWidth);
        mbMain.MelodicInterludeWindow:Redraw();
    end
	y = y + 15;



	y = y + 20; -- Space the Debug Options out more.
	if (SHOW_DEBUG_OPTIONS) then
		self.debugSectionLabel = Turbine.UI.Label();
		self.debugSectionLabel:SetParent(parent);
		self.debugSectionLabel:SetSize(200, 30);
		self.debugSectionLabel:SetPosition(20, y);
		self.debugSectionLabel:SetText("Debug Options");
		y = y + 30;

		self.debugClearBalladsButton = Turbine.UI.Lotro.Button();
		self.debugClearBalladsButton:SetParent( parent );
		self.debugClearBalladsButton:SetPosition(20, y);
		self.debugClearBalladsButton:SetSize(150, 20);
		self.debugClearBalladsButton:SetText("Clear Ballads");
		self.debugClearBalladsButton.Click = function(sender, args)
			DEBUG_IGNORE_BALLAD_EFFECTS = true;
			mbMain:RefreshEffectDisplay();
			DEBUG_IGNORE_BALLAD_EFFECTS = false;
		end
		y = y + 30;

		self.debugEnterCombatButton = Turbine.UI.Lotro.Button();
		self.debugEnterCombatButton:SetParent(parent);
		self.debugEnterCombatButton:SetPosition(20, y);
		self.debugEnterCombatButton:SetSize(150, 20);
		self.debugEnterCombatButton:SetText("Enter Combat");
		self.debugEnterCombatButton.Click = function(sender, args)
			local isInCombat = true;
			mbMain:HandleCombatChanged(isInCombat);
		end
		y = y + 30;

		self.debugExitCombatButton = Turbine.UI.Lotro.Button();
		self.debugExitCombatButton:SetParent(parent);
		self.debugExitCombatButton:SetPosition(20, y);
		self.debugExitCombatButton:SetSize(150, 20);
		self.debugExitCombatButton:SetText("Exit Combat");
		self.debugExitCombatButton.Click = function(sender, args)
			local isInCombat = false;
			mbMain:HandleCombatChanged(isInCombat);
		end
		y = y + 30;

		self.debugDetectMelodicInterludeStart = Turbine.UI.Lotro.Button();
		self.debugDetectMelodicInterludeStart:SetParent(parent);
		self.debugDetectMelodicInterludeStart:SetPosition(20, y);
		self.debugDetectMelodicInterludeStart:SetSize(200, 20);
		self.debugDetectMelodicInterludeStart:SetText("Start Melodic Interlude");
		self.debugDetectMelodicInterludeStart.Click = function(sender, args)
			local mock = self:GetDebugEffect("Melodic Interlude");
			mbMain:EffectAdded(nil, mock);
		end
		y = y + 30;

		self.debugDetectMelodicInterludeStop = Turbine.UI.Lotro.Button();
        self.debugDetectMelodicInterludeStop:SetParent(parent);
        self.debugDetectMelodicInterludeStop:SetPosition(20, y);
        self.debugDetectMelodicInterludeStop:SetSize(200, 20);
        self.debugDetectMelodicInterludeStop:SetText("Stop Melodic Interlude");
        self.debugDetectMelodicInterludeStop.Click = function(sender, args)
			local mock = self:GetDebugEffect("Melodic Interlude");
			mbMain:EffectRemoved(nil, mock);
        end
        y = y + 30;


	end

end

function OptionWindow:GetDebugEffect(effectName)
	local mock = {
		Effect = {
			GetName = function() return effectName; end
		};
	};
	return mock;
end

function OptionWindow:Show()
	self:SetVisible(true);
end

function OptionWindow:ThemeChanged(sender)
	self:ColorListBoxIndex(sender);
	self.settings:SetThemeIndex(sender:GetSelectedIndex());	
end

function OptionWindow:ColorListBoxIndex(sender)
	for i = 1, sender:GetItemCount() do
		local listItem = sender:GetItem(i);
		if (i == sender:GetSelectedIndex()) then
			listItem:SetBackColor( Turbine.UI.Color( 1, 0.4, 0.4, 0.4 ) );
		else
			listItem:SetBackColor( Turbine.UI.Color( 1, 0.3, 0.3, 0.3 ) );
		end
	end
end
